@@ -51,11 +51,13 @@ class BasePaymentModality(models.Model):
 
 
 EXCHANGE = Choices(
-    ('OFFER',   1,  _(u'Product or Service Offer')),
-    ('NEED',    2,  _(u'Product or Service Need')),
-    ('MUTU',    3,  _(u'Mutualization')),
-    ('COOP',    5,  _(u'Cooperation, partnership')),
-    ('QA',      6,  _(u'Question')),
+    ('P_OFFER',   1,  _(u'Product Offer')),
+    ('S_OFFER',   2,  _(u'Service Offer')),
+    ('P_NEED',    3,  _(u'Product Need')),
+    ('S_NEED',    4,  _(u'Service Need')),
+    ('MUTU',    7,  _(u'Mutualization')),#3
+    ('COOP',    8,  _(u'Cooperation, partnership')),#5
+    ('QA',      9,  _(u'Question')),#6
 )
 
 class BaseExchange(models.Model):
